@@ -211,7 +211,7 @@ class GetS3Handler(AWSConfig):
         else:
             command = f"""aws s3 cp {dryrun_pattern} "s3://{bucket_name}/{s3_path}" "{local_path}" {exclude_filter_pattern} {include_filter_pattern} --request-payer "requester" --profile {self.AWS_PROFILE_NAME} """
         
-        print(command)
+        # print(command)
         
         try:
             process = Popen(command,shell=True,stdout=PIPE)
